/*
 * Connect to a JIRA instance and retrieve an issue
 */
package com.perforce.ts.rest;

import java.io.Console;

/**
 *
 * @author jbrown
 */
public class TestConnect {

    /**
     * Params:
     * 1: JIRA url
     * 2: username or username:password. If password not provided, prompt
     * 3: issue. If not provided, just connect and getServerDate.
     *
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        // arg check
        int rc = 1;
        try {
            rc = mainWork(args);
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        System.exit(rc);
    }

    public static int mainWork(String[] args) throws Exception {
        // arg check
        if (args.length < 2) {
            printUsage();
            return 64;
        }
        String url = args[0];
        String user = args[1];
        String password = null;
        int userColon = user.indexOf(":");
        if (userColon > 0) {
            password = user.substring(userColon + 1);
            user = user.substring(0, userColon);
        } else if (hasStdin) {
            // prompt for password
            StringBuilder sb = new StringBuilder();
            try {
                Console cons;
                System.out.print("Password: ");
                char[] passwd = System.console().readPassword();
                password = new String(passwd);
            } catch (Exception e) {
                e.printStackTrace();
                return 66;
            }
        } else {
            return 66;
        }
        String issue = null;
        if (args.length > 2) {
            issue = args[2];
        }
        System.out.println("");
        RestConnect rconn = new RestConnect();
        return rconn.connectAndRun(url, user, password, issue, (args.length > 3 ? args[3] : (String)null));

    }

    private static void printUsage() {
        System.out.println("Usage:   ");
        System.out.println("  java -jar jiraRestAccess.jar <url> <username:password> [<issue> [appendSummary] ]  ");
        System.out.println("where:");
        System.out.println("   url is the JIRA url, e.g.,  http://myjira:8080/");
        System.out.println("   username:password is the user to connect to JIRA with.  If password not provided, will prompt");
        System.out.println("   issue (optional) is an issue an retrieve.  If not provided, just connect and quit");
        System.out.println("   summaryAppend (optional) if provided, append this to the end of the summary");
    }
    protected static boolean hasStdin = true; // for testing
}
